@@ -5,7 +5,7 @@ fn main() -> Result<(), OwaError> {
     let owa = Owa4x::new();
     owa.init()?;
 
-    owa.take_a_nap();
+    owa.take_a_nap(30)?;
 
     Ok(())
 }
